@@ -4,6 +4,10 @@
 
   if (file.exists(config_file)) {
     config <- yaml::yaml.load_file(config_file)
+    if ("set_fields" %in% names(config)) {
+      sinew_opts$set(list(add_fields = config[["set_fields"]]))
+      config[["set_fields"]] <- NULL
+    }
     if ("add_fields" %in% names(config)) {
       sinew_opts$append(config["add_fields"])
       config[["add_fields"]] <- NULL
